/*
 * table.c - set up translation tables for texi2roff
 *		Release 1.0a	August 1988
 *		Release 2.0	January 1990
 *		Release 3.0beta	January 1991
 *
 *	BETA Version	- DO NOT REDISTRIBUTE!
 *
 * Copyright 1988, 1989, 1990, 1991  Beverly A.Erlebacher
 * erlebach@cs.toronto.edu    ...uunet!utai!erlebach
 *
 *
 * When adding more commands: 
 *
 * - be sure that gettoken() can recognize not just the ending token
 *   (texend) but also the end of the starting token (texstart) for
 *   the command, if it doesnt already occur in a table.
 *
 * - keep the tables sorted
 *
 * - try to keep all troff strings here and in the tablem?.c files
 *
 * - strive diligently to keep the program table-driven
 */

#include <stdio.h>	/* just to get NULL */
#include "texi2roff.h"

extern struct misccmds macmds, mecmds, mmcmds, mscmds;
extern struct tablerecd metable[], mmtable[], mstable[], matable[];
extern int	metablesize, mmtablesize, mstablesize, matablesize;

char	indexmacro[] = ".de iX \n.tm \\\\$1   \\\\n%\n..";
char	trquotes[] = ".tr \\(is'\n.tr \\(if`\n.tr \\(pd\"";
char	monthsetup[] =
".if \\n(mo=1 .ds MO January\n.if \\n(mo=2 .ds MO February\n\
.if \\n(mo=3 .ds MO March\n.if \\n(mo=4 .ds MO April\n\
.if \\n(mo=5 .ds MO May\n.if \\n(mo=6 .ds MO June\n\
.if \\n(mo=7 .ds MO July\n.if \\n(mo=8 .ds MO August\n\
.if \\n(mo=9 .ds MO September\n.if \\n(mo=10 .ds MO October\n\
.if \\n(mo=11 .ds MO November\n.if \\n(mo=12 .ds MO December";

struct misccmds *cmds;
struct tablerecd *table, *endoftable;

void
initialize(macropkg, makeindex)
int	macropkg;
int	makeindex;
{
	int	tablesize;

	switch (macropkg) {
	case MS:
		table = mstable;
		tablesize = mstablesize;
		cmds = &mscmds;
		break;
	case MM:
		table = mmtable;
		tablesize = mmtablesize;
		cmds = &mmcmds;
		break;
	case ME:
		table = metable;
		tablesize = metablesize;
		cmds = &mecmds;
		break;
	case MA:
		table = matable;
		tablesize = matablesize;
		cmds = &macmds;
		break;
	}
	endoftable = table + tablesize / sizeof table[0];
	puts(cmds->init);
	if (macropkg != MA) {
		if (makeindex == YES)
			puts(indexmacro);
		puts(trquotes);
		puts(monthsetup);
	}
}



/*
 * lookup - linear search for texinfo command in table
 * i used bsearch() for a while but it isnt portable and makes lint squawk.
 */

struct tablerecd *
lookup(token)
char	*token;
{
	register struct tablerecd *tptr;

	for (tptr = table; tptr < endoftable; ++tptr) {
		if (STREQ(tptr->texstart, token))
			return tptr;
	}
	return NULL;
}


